@@ -48,22 +48,19 @@
 
 require_once 'SPAF2/ApplicationConfig.php';
 require_once 'SPAF2/DBAccess.php';
-require_once 'SPAF2/AppUtils.php';
 
 class Application extends ApplicationConfig
 {
     /**
-     * _authz | authz
+     * authz
      *
      * Array with authorization mappings.
      *
      * @access public
      * @var array
      */
-    var $_authz;
     var $authz;
 
-
     /**
      * array with config parameters
      *
@@ -72,15 +69,6 @@ class Application extends ApplicationConfig
      */
     var $config;
 
-
-    /**
-     * ApplicationError object
-     *
-     * @access public
-     * @var object ApplicationError
-     */
-    var $Error;
-
     /**
      * _output
      *
@@ -140,6 +128,7 @@ class Application extends ApplicationConfig
      */
     var $configdir;
 
+
     /**
      * _session
      *
@@ -180,15 +169,6 @@ class Application extends ApplicationConfig
     var $TPL;
 
 
-    /**
-     * skin
-     *
-     * Holds the name of the skin subdir
-     *
-     * @access public
-     */
-    var $skin;
-
 
     /**
      * lang
@@ -210,10 +190,49 @@ class Application extends ApplicationConfig
     var $date_format;
 
 
+    /**
+     * time_format
+     *
+     * Holds the current time format 
+     *
+     * @access public
+     */
+    var $time_format;
+
+
+    /**
+     * locale_msg
+     *
+     * Filename of the message file
+     *
+     * @access public
+     */
+    var $locale_msg;
+
+
+    /**
+     * locale_txt
+     *
+     * Filename of the localized texts
+     *
+     * @access public
+     */
+    var $locale_txt;
+
+
+    /**
+     * skin
+     *
+     * Name of the skin(dir)
+     *
+     * @access public
+     */
+    var $skin;
+
     /**
      * template
      *
-     * Holds the current templacte to render.
+     * Holds the current template to render.
      *
      * @access public
      */
@@ -221,13 +240,13 @@ class Application extends ApplicationConfig
 
 
     /**
-     * message_file
+     * tpl_root 
      *
-     * Filename of the message file
+     * Directory with skindirs and message files
      *
      * @access public
      */
-    var $message_file;
+    var $tpl_root;
 
 
     /**
@@ -267,114 +286,22 @@ class Application extends ApplicationConfig
     {
 
         $this->_debug_vars = array();
-        $this->configfile = basename($configfile);
         $this->configdir = dirname($configfile);
 
         $AppConfig = new ApplicationConfig($this->configdir);
-        $this->config = $AppConfig->load($this->configfile);
-        $this->_authz = $AppConfig->load($this->config['AUTHORIZATION']);
-        $this->authz  = $this->_authz;
+        $this->config = $AppConfig->load(basename($configfile));
+        $this->authz = $AppConfig->load($this->config['AUTHORIZATION']);
 
         $this->module   = $MODULE;
         $this->_request = & $_REQUEST;
         $this->_session = & $_SESSION;
         $this->DEBUG = $this->getConfig('DEBUG');
 
-        // Language settings
-        $default_locale = $this->getConfig('DEFAULT_LANGUAGE');
-        if ($this->getParam('LANG')) {
-            $this->lang = $this->getParam('LANG');
-        }
-        elseif ($this->getSession('LANG')) {
-            $this->lang = $this->getSession('LANG');
-        }
-        else {
-            $this->lang = AppUtils::GetLocaleFromBrowser($default_locale, false);
-        }
-        $this->setSession('LANG',$this->lang);
+        $this->tpl_root = getcwd().'/'.$this->config['TEMPLATE_ROOT'].'/templates';
 
-        // date format
-        switch ($this->lang) {
-            case 'de':
-                $this->date_format = '%d.%m.%Y';
-                break;
-            case 'en':
-                $this->date_format = '%m/%d/%Y';
-                break;
-        }
-
-
-        if ($this->getParam('SKIN')) {
-            $this->skin = $this->getParam('SKIN');
-        }
-        elseif ($this->getSession('SKIN')) {
-            $this->skin = $this->getSession('SKIN');
-        }
-        else {
-            $this->skin = 'default';
-        }
-
-        // Template initialization
         $this->TPL = new Smarty;
         $this->TPL->compile_check = true;
 
-        if(array_key_exists('TEMPLATE_ROOT',$this->config)) {
-            $tpl_root = getcwd().'/'.$this->config['TEMPLATE_ROOT'].'/templates';
-        }
-        else {
-            $tpl_root = getcwd().'/templates';
-        }
-
-        if ($this->skin) {
-            $skin_dir = $tpl_root.'/'.$this->skin;
-        }
-        // fallback
-        if (! is_file($skin_dir.'/header.tpl')) {
-            $skin_dir = $tpl_root.'/default';
-        }
-        $this->TPL->template_dir = $skin_dir;
-
-        $message_file = $tpl_root.'/'.$this->lang.'.msg';
-        if (! is_readable($message_file)) {
-            $message_file = $tpl_root.'/'.$default_locale.'.msg';
-        }
-
-        // skin localization
-        $locale_text = $tpl_root.'/'.$this->lang.'.txt';
-        if (! is_readable($locale_text)) {
-            $locale_text = $tpl_root.'/'.$default_locale.'.txt';
-        }
-
-        // messages from file
-        $this->message_file = $message_file;
-        $this->Error = new ApplicationError ($message_file);
-
-        $this->log('template_dir '.$skin_dir,2,'SPAF2/App');
-        $templates_cache_base = $this->getConfig('TEMPLATE_CACHE');
-        $templates_cache_skin = $templates_cache_base.'/'.$this->skin;
-        if (!is_dir($templates_cache_skin)) {
-            mkdir($templates_cache_skin);
-        }
-        if (is_writable($templates_cache_skin)) {
-            $this->TPL->compile_dir = $templates_cache_skin;
-        }
-        else {
-            $this->log('WARNING: Cannot write to templates cache: '.$templates_cache_skin,0,'SPAF2/App');
-            $this->TPL->compile_dir = '/tmp';
-        }
-        $this->TPL->config_dir   = $this->configdir;
-        $this->TPL->cache_dir    = $tpl_root . '/cache';
-        $this->TPL->assign('LOCALE_TEXT',$locale_text);
-        $this->TPL->assign('SN',session_name());
-        $this->TPL->assign('SID',session_id());
-        $this->TPL->assign('CA',$this->getParam('CA'));
-        $this->TPL->assign_by_ref('ERROR',$this->Error);
-
-        if ($DEBUG = $this->getParam('DEBUG')) {
-            $this->setSession('DEBUG',$DEBUG);
-        }
-        $this->TPL->assign('DEBUG',$this->DEBUG);
-
         if (isset($this->config['DBTYPE'])) {
             $this->DB = new DBAccess($this->config['DBTYPE'],$this->config['DBUSER'],
                                      $this->config['DBPASS'],$this->config['DBHOST'],
@@ -423,13 +350,13 @@ class Application extends ApplicationConfig
         {
             $authorized = Authorization::check($action,$this);
         }
-        elseif (isset($this->_authz[$action])) {
-            if ($this->accessLevel() >= $this->_authz[$action]) {
+        elseif (isset($this->authz[$action])) {
+            if ($this->accessLevel() >= $this->authz[$action]) {
                 $authorized = TRUE;
             }
         }
         if (! $authorized) {
-            $this->setError('ERR_AUTHZ');
+            $this->setMsg('ERR_AUTHZ');
         }
         return $authorized;
     }
@@ -521,6 +448,37 @@ class Application extends ApplicationConfig
     }
 
 
+    /**
+     * configure template set
+     *
+     * Settings for all templates
+     *
+     * @access public
+     */
+    function tplConfig()
+    {
+        // initialize cache
+        $templates_cache_base = $this->getConfig('TEMPLATE_CACHE');
+        $templates_cache_skin = $templates_cache_base.'/'.$this->skin;
+        if (!is_dir($templates_cache_skin)) {
+            mkdir($templates_cache_skin);
+        }
+        if (is_writable($templates_cache_skin)) {
+            $this->TPL->compile_dir = $templates_cache_skin;
+        }
+        else {
+            $this->log('warning: cannot write to templates cache: '.$templates_cache_skin,0,'spaf2/app');
+            $this->TPL->compile_dir = '/tmp';
+        }
+        $this->TPL->config_dir   = $this->configdir;
+        $this->TPL->cache_dir    = $this->tpl_root . '/cache';
+
+        if ($debug = $this->getparam('DEBUG')) {
+            $this->setsession('DEBUG',$debug);
+        }
+    }
+
+
     /**
      * Calls (require) the file
      *
@@ -553,29 +511,18 @@ class Application extends ApplicationConfig
         if ($module) {
             $view = $module;
         }
-        if ($this->DEBUG >= $threshold) {
-            error_log("[$threshold:$view] $message");
+
+        $debug_vals   = preg_split('/,(\s+)?/',$this->DEBUG);
+        $debug_global = array_shift($debug_vals);
+        foreach ($debug_vals as $debug_entry) {
+            list($debug_module,$level) = explode(':',$debug_entry);
+            if (($debug_module == $module) && ($level >= $threshold)) {
+                error_log("[$threshold:$view] $message");
+                return;
+            }
         }
-    }
-
-
-    /**
-     * debug
-     *
-     * Perform debugging
-     *
-     * Shows the debugging console if the $debug parameter is set in
-     * session and in configuration.
-     *
-     * @access public
-     * @param string $debug
-     */
-    function debug ($debug)
-    {
-        $debug_val = $this->getSession('DEBUG');
-        if ($debug && $debug_val) {
-            $AppDebug = new ApplicationDebug($this->TPL,$this->_request,$this->_session,$this->_debug_vars);
-            $this->_output .= $AppDebug->debug($debug_val);
+        if ($debug_global >= $threshold) {
+            error_log("[$threshold:$view] $message");
         }
     }
 
@@ -597,7 +544,7 @@ class Application extends ApplicationConfig
 
 
     /**
-     * Returns the output to the browser.
+     * Initialize template engine and return output
      *
      * @access public
      *
@@ -694,21 +641,6 @@ class Application extends ApplicationConfig
     }
 
 
-    /**
-     * getVar
-     *
-     * Returns the value of the variable.
-     *
-     * @access public
-     * @param string $var Name of the variable
-     * @return misc
-     */
-    function getVar($var)
-    {
-        return $this->_vars[$var];
-    }
-
-
     /**
      * Redirect to another action/view
      *
@@ -805,26 +737,6 @@ class Application extends ApplicationConfig
     }
     
 
-    /**
-     * getErrorList
-     *
-     * Get the list of error messages if error is set.
-     *
-     * @access public
-     * @param string $error symbol
-     * @return $int error count
-     */
-    function getErrorList ($error='')
-    {
-        if ($count = $this->Error->count) {
-            return $this->Error->messages;
-        }
-        else {
-            return $count;
-        }
-    }
-
-
     /**
      * getMsg
      *
@@ -839,8 +751,8 @@ class Application extends ApplicationConfig
     function getMsg ($msg_sym='')
     {
         $msg_string = '';
-        if (! $fd = @fopen ($this->message_file, "r")) {
-	        $this->log('ERROR: Cannot read message file '.$this->message_file,0,'SPAF2/App');
+        if (! $fd = @fopen ($this->locale_msg, "r")) {
+	        $this->log('ERROR: Cannot read message file '.$this->locale_msg,0,'SPAF2/App');
         }
         else {
             while (!feof ($fd)) {
@@ -864,6 +776,52 @@ class Application extends ApplicationConfig
     }
 
  
+    /**
+     * setLang
+     *
+     * Sets attributes:
+     *
+     * ->lang
+     * ->locale_msg
+     * ->locale_txt
+     * ->date_format
+     * ->time_format
+     *
+     * @access public
+     * @param string $locale
+     */
+    function setLang($language)
+    {
+        $default_language = $this->getConfig('DEFAULT_LANGUAGE','de');
+        if ($language == 'DEFAULT_LANGUAGE') {
+            $language = $default_language;
+        }
+        $this->lang = $language; 
+
+        // skin localization
+        $locale_txt = $this->tpl_root.'/'.$this->lang.'.txt';
+        if (!is_readable($locale_txt)) {
+            $locale_txt = $this->tpl_root.'/'.$default_language.'.txt';
+        }
+        $this->locale_txt = $locale_txt;
+        // messages
+        $locale_msg = $this->tpl_root.'/'.$this->lang.'.msg';
+        if (!is_readable($locale_msg)) {
+            $locale_msg = $this->tpl_root.'/'.$default_language.'.msg';
+        }
+        $this->locale_msg = $locale_msg;
+
+        // date|time format
+        if (preg_match('/^en/',$this->lang)) {
+            $this->date_format = '%m/%d/%Y';
+        }
+        else {
+            $this->date_format = '%d.%m.%Y';
+        }
+        $this->time_format = '%H:%M';
+    }
+
+
     /**
      * setMsg
      *
@@ -881,340 +839,28 @@ class Application extends ApplicationConfig
         $this->assign('MSG',$msg_string);
         return TRUE;
     }
- 
-    
+
+
     /**
-     * setError
+     * setSkin
      *
-     * Set error message according to the error symbol.
-     *
-     * Fetches the error message from the file $confdir/error.msg.
+     * Set skin directory.
      *
      * @access public
-     * @param string $error symbol
-     * @return $int error count
+     * @param $skin string
      */
-    function setError ($error)
+    function setSkin($skindir='')
     {
-        if ($error) {
-            $count = $this->Error->setError($error);
-        } 
-        return $count;
-    }
-
-    
-    /**
-     * Sets the application variable
-     *
-     * @access public
-     * @param string $var Name of the parameter
-     * @return string $var value of the parameter
-     */
-    function setVar($var,$value)
-    {
-        return $this->_vars[$var] = $value;
-    }
-
-}
-
-
-/**
- * @package Application
- */
-/**
- * Debug class
- */
-
-class ApplicationDebug extends Application
-{
-    /**
-     * TPL
-     *
-     * Template engine (Smarty) object.
-     *
-     * @access public
-     */
-    var $TPL;
-
-    /**
-     * _request
-     *
-     * Reference to the request parameters.
-     *
-     * @access public
-     */
-    var $_request;
-
-    /**
-     * _session
-     *
-     * Reference to the session parameters.
-     *
-     * @access public
-     */
-    var $_session;
-    
-
-    /**
-     * _debug_vars
-     *
-     * Reference to the debug vars of the application.
-     *
-     * @access public
-     */
-    var $_debug_vars;
-
-    /**
-     * _output
-     *
-     * Output string.
-     *
-     * @access public
-     */
-    var $_output;
-
-    /**
-     * Constructor
-     *
-     * @param object $Smarty
-     * @return object
-     */
-    public function __construct(&$TPL,&$request,&$session,&$debug_vars)
-    {
-        $this->TPL = &$TPL;
-        $this->_request = &$request;
-        $this->_session = &$session;
-        $this->_debug_vars = &$debug_vars;
-    }
-
-    /**
-     * debug
-     *
-     * Show the debug information depending of the debugging value.
-     *
-     * 1 = REQUEST Parameters
-     * 2 = SESSION Parameters
-     * 3 = REQUEST + SESSION
-     * 256 = Smarty debugging console
-     *
-     * @access public
-     */
-    function debug ($debug_val)
-    {
-        if ($this->_isBitSet($debug_val,1))    $this->request();
-        if ($this->_isBitSet($debug_val,2))    $this->session();
-        if ($this->_isBitSet($debug_val,3))    $this->variable();
-        if ($this->_isBitSet($debug_val,9))    $this->template();
-
-        // custom debug template
-        //$this->compile(SMARTY_DIR.'DEBUG.tpl');
-        $this->compile($this->TPL->template_dir.'/DEBUG.tpl');
-        return $this->_output;
-    }
-
-
-    /**
-     * smarty
-     *
-     * Show Smarty debugging console.
-     *
-     */
-    function template () {
-        $this->TPL->debugging = TRUE;
-    }
-
-
-    /**
-     * request
-     *
-     * Show values of request parameters.
-     *
-     */
-    function request () {
-        $vars = array(); $vals = array();
-        $request = $this->_request;
-        ksort($request);
-        foreach ($request as $var => $val) {
-            if ($var == 'DEBUG' || $var == session_name())
-                continue;
-            array_push($vars,$var);
-            array_push($vals,$val);
+        if (!$skindir) {
+            $skindir = 'default';
         }
-        $this->TPL->assign('DEBUG_REQUEST','1');
-        $this->TPL->assign('_request_params',$vars);
-        $this->TPL->assign('_request_values',$vals);
-     }
-
-
-    /**
-     * session
-     *
-     * Show values of session parameters.
-     *
-     */
-    function session () {
-        $vars = array(); $vals = array();
-        $request = $this->_session;
-        ksort($request);
-        foreach ($request as $var => $val) {
-            if ($var == 'DEBUG' || $var == session_name())
-                continue;
-            array_push($vars,$var);
-            array_push($vals,$val);
+        $this->skin = $skindir;
+        $tpl_dir  = $this->tpl_root.'/'.$skindir;
+        if (!is_file($tpl_dir.'/header.tpl')) {
+            $this->log("Warning: Skin $tpl_dir not initialized.",2,'spaf2/app');
+            $tpl_dir = $this->tpl_root.'/default';
         }
-        $this->TPL->assign('DEBUG_SESSION','1');
-        $this->TPL->assign('_session_params',$vars);
-        $this->TPL->assign('_session_values',$vals);
-    }
-
-
-    /**
-     * debug variable
-     *
-     * Show values of variable
-     *
-     */
-    function variable () {
-        $variable = $this->_debug_vars;
-        $vars = array(); $vals = array();
-
-        $a = 1; $o = 1; $v = 1;
-        foreach ($variable as $pos => $content) {
-            if (is_array($content)) {
-                ksort($content);
-                array_push($vars,'<b>Array_'.$a++.'</b>');
-                array_push($vals,' ');
-                foreach ($content as $var => $val) {
-                    array_push($vars,'&nbsp;'.$var.' => ');
-                    array_push($vals,$val);
-                }
-            }
-            elseif ($class = get_class($content)) {
-                array_push($vars,'<b>Object_'.$o++.':</b>');
-                array_push($vals,ucfirst($class));
-                $ovars = get_object_vars($content);
-                foreach ($ovars as $var => $val) {
-                    array_push($vars,'&nbsp;->'.$var);
-                    array_push($vals,$val);
-                }
-            }
-            else {
-                array_push($vars,'Variable: '.$v++);
-                array_push($vals,$content);
-            }
-        }   
-        $this->TPL->assign('DEBUG_VARIABLE','1');
-        $this->TPL->assign('_variable_params',$vars);
-        $this->TPL->assign('_variable_values',$vals);
-    }
-
-    // check bitmask
-    function _isBitSet($mask,$num)
-    {
-        return (($mask& (0x01 << ($num-1))));
-    }
-}
-
-// require_once 'SPAF2/ApplicationError.php';
-
-/**
- * ApplicationError
- */
-class ApplicationError extends Application
-{
-    /**
-     * error counter
-     *
-     * @var int $count
-     * @access public
-     */
-    var $count;
-
-    /**
-     * error messages array
-     *
-     * @var array $messages
-     * @access public
-     */
-    var $messages;
-
-    /**
-     * _errormsg
-     *
-     * @var string $_errormsg
-     * @access public
-     */
-    var $_errormsg;
-
-    
-    /**
-     * constructor
-     *
-     * @param string $msgfile message file
-     * @access public
-     */
-    function ApplicationError ($msgfile)
-    {
-        $this->count = 0;
-        $this->_errormsg = $msgfile;
-        $this->messages = array();
-    }
-
-
-    /**
-     * getLast
-     *
-     * Returns the last error message set.
-     *
-     * @access public
-     * @return string errormessage
-     */
-    function getLast ()
-    {
-        return end($this->messages);
-    }
-
-    /**
-     * setError
-     *
-     * Set error message.
-     *
-     * Fetches the error message from the file $confdir/error.msg.
-     *
-     * @access public
-     * @param string $error symbol
-     * @return $int error count
-     */
-    function setError ($error)
-    {
-        $file = $this->_errormsg;
-        if (file_exists($file)) {
-            $fd = fopen ($file, "r");
-            $notfound = 1;
-            while (!feof ($fd)) {
-                $buffer = fgets($fd, 1024);
-                if (preg_match("/^$/",$buffer)) {
-                    continue;
-                }
-                if (preg_match("/^#/",$buffer)) {
-                    continue;
-                }
-                @list($sym,$msg) = preg_split("/\s*=\s*/",$buffer);
-                if ($sym == $error) {
-                    $notfound = '';
-                    $this->count = array_push($this->messages,$msg);
-                }
-            }
-            fclose($fd);
-        }
-        else {
-            $notfound = 1;
-        }
-        if ($notfound == 1) {
-            $this->log("Undefined error sym: $error",0,'SPAF2/App');
-            $this->count = array_push($this->messages,$error);
-        }
-        return $this->count;
+        $this->TPL->setTemplateDir($tpl_dir);
     }
 }
 
