@@ -55,6 +55,9 @@ try {
         throw new Exception("Cannot write mail to \"$sendmail\"");
     }
     fclose($ph);
+
+    $bennoId = QueryResult::getBennoId($sessionMailId);
+    $Audit->log("MAIL $Backend->archive:".$bennoId.' >> '.$mailTo);
 }
 catch (Exception $e) {
     $App->log('[a_forward] '.$e->getMessage());
