@@ -49,7 +49,7 @@ try {
 }
 catch (Exception $e) {
     $App->log('[downloadAttachment] '.$e->getMessage());
-    $App->setError($e->getMessage());
+    $App->setMsg($e->getMessage());
     $App->view = 'error';
 }
 
