@@ -57,7 +57,7 @@ try {
 }
 catch (Exception $e) {
     $App->log('[downloadMail] '.$e->getMessage());
-    $App->setError($e->getMessage());
+    $App->setMsg($e->getMessage());
 }
 
 $App->view = 'showList';
