@@ -49,14 +49,12 @@ if (! $pass) {
     $App->redirect('default',array('MSG'=>'ERR_NOPASS'));
 }
 
-
 $User = new User($userid);
 try {
-    $User->loadExternal($authscript,$pass);
-}
-catch (Exception $e) {
-    $exc = $e->getMessage();
-    if ($exc == 'ERR_EXECUTE') {
+    if ($authscript) {
+        $User->loadExternal($authscript,$pass);
+    }
+    else {
         $User->load();
         // check authentication
         if ($User->password != md5($pass)) {
@@ -65,16 +63,19 @@ catch (Exception $e) {
             $App->redirect('default',array('MSG'=>'ERR_AUTH'));
         }
     }
-    else {
-        $App->log('Authentication error: '.$exc);
-        $App->redirect('default',array('MSG'=>$exc));
-    }
 }
+catch (Exception $e) {
+    $exc = $e->getMessage();
+    $App->log('Authentication error: '.$exc);
+    $App->redirect('default',array('MSG'=>$exc));
+}
+
 $App->log('Authentication of '.$User->id. ' successful',1);
 // LOGIN SUCCESSFUL
 
 // initialize backend
-$archive = end($User->getArchives());
+$archive_list = $User->getArchives();
+$archive = end($archive_list);
 $FilterList = Filter::FetchList($User);
 $filterString = '';
 foreach ($FilterList as $Filter) {
@@ -95,24 +96,29 @@ $App->setSession('ExtQuery',$ExtQuery);
 
 $App->setSession('QueryList',StoredQuery::FetchList($User->id));
 
-// restore search mask state
+// restore state of last session
 try {
-    $AppState = new AppState('searchMaskState',$User->id);
-    $AppState->load();
-    if ($AppState->value) {
-        $App->setSession('searchMaskState',$AppState->value);
-        $App->assign('searchMaskState',$searchMaskState);
+    // searchMask
+    $AppState = new AppState($User->id);
+    $searchMaskState = $AppState->getValue('searchMaskState','Simple');
+    $App->setSession('searchMaskState',$searchMaskState);
+
+    // Language
+    if ($App->getParam('interfaceLanguage')) {
+        $AppState->setValue('userLanguage',$App->getParam('interfaceLanguage'));
+        $App->setLang($App->getParam('interfaceLanguage'));
+    }
+    else {
+        $userLanguage = $AppState->getValue('userLanguage');
+        if ($userLanguage) {
+            $App->setLang($userLanguage);
+        }
     }
 }
 catch (Exception $e) {
     $App->log('Error loading application state: '.$e->getMessage());
 }
 
-// Store skin in session
-if ($App->getSession('language')) {
-    $App->setSession('SKIN',$App->getParam('language'));
-}
-
 // redirect user to search mask
 $App->redirect('greeting');
 
