@@ -38,7 +38,11 @@ try {
     $StoredQuery = new StoredQuery($queryId);
     $StoredQuery->load();
 
-    $ExtQuery = $StoredQuery->query;
+    $ExtQuery = $StoredQuery->getQuery();
+
+    // show extended Search
+    $searchMaskState = $ExtQuery->type;
+    $App->setSession('searchMaskState',$searchMaskState);
 
     // fresh search, thus we start with position 1
     $QueryResult = $Backend->query($ExtQuery,0,$search_limit);
@@ -48,10 +52,6 @@ try {
     }
     $sessionMailId = $QueryResult->getSessionMailId(0);
 
-    // show extended Search
-    $searchMaskState = 'Ext';
-    $App->setSession('searchMaskState',$searchMaskState);
-    $App->assign('searchMaskState',$searchMaskState);
 }
 catch (Exception $e) {
     if ($e->getMessage() == 'ID_NOT_FOUND') {
