@@ -40,8 +40,6 @@ $sessionMailId = $App->getParam('id');
 
 try {
     $EMail = $Backend->fetch($sessionMailId);
-    $displayedMailId = $sessionMailId;
-    $App->setSession('displayedMailId',$displayedMailId);
 }
 catch (Exception $e) {
     $App->log($e->getMessage());
