@@ -67,7 +67,9 @@ class Backend
      */
     function fetch ($sessionMailId)
     {
+        global $App;
         $bennoId = QueryResult::getBennoId($sessionMailId);
+        $App->log("Fetch mail from archive: $bennoId",3,'Backend');
 
         $request_url  = $this->base_url.'/mail/';
         $query_string = 'archive='.$this->archive.
@@ -80,6 +82,7 @@ class Backend
         $header = $maildata['header'];
 
         $EMail = new EMail($sessionMailId,$bennoId,$header['From'],$header['To'],$header['Cc'],$header['Bcc'],$header['Subject'],$header['Date'],$header['Size'],$body);
+        $EMail->verified = $header['HashCheckPassed'];
 
         foreach ($maildata['attachments'] as $atm) {
             $Attachment = new Attachment($atm['name'],@$atm['content-type'], $atm['size']);
@@ -196,8 +199,9 @@ class Backend
      */
     function query ($Query,$startNum=0,$limit=20)
     {
-
         global $App;
+        global $Audit;
+
         if (empty($this->filter)) {
             $this->filter = 'NOT*';
         }
@@ -211,6 +215,9 @@ class Backend
                  '&sortAsc='.$Query->getSortAsc() .
                  '&query='.$Query->getQuery();
 
+        $App->log("Query string: $query",4,'Backend');
+        $App->log("Filter string: $query",5,'Backend');
+
         $resultList = $this->_curl_query($request_url,$query);
 
         if (! preg_match('/^LICENSE_VALID/',$resultList['licenseValid'])) {
@@ -219,6 +226,8 @@ class Backend
                 throw new Exception('LICENSE_ERROR');
             }
         }
+        $Audit->log("QUERY $this->archive:".$Query->getQuery().' && '.$this->filter);
+
         $QueryResult = new QueryResult($resultList,$Query,$limit);
         return $QueryResult;
     }
@@ -255,12 +264,15 @@ class Backend
         if (preg_match('/^https:/',$request_url)) {
             if ($this->rest_ssl_verify == 'YES') {
                 curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, true);
+                curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, true);
             }
             else {
                 curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
+                curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, false);
             }
         }
 
+         $App->log('Request URL: '.$request_url."?".$query,4,'Backend');
         if (($response = curl_exec($curl)) === false) {
             $errnum = curl_errno($curl);
             $App->log('[Backend/query] Request error: '.curl_error($curl).'['.$errnum.']');
