@@ -54,9 +54,10 @@ class EMail
 
     var $hasAttachment;
     var $attachments;
+    var $verified;
 
 
-    function EMail ($id,$bennoId='',$from='',$to=array(),$cc=array(),$bcc=array(),$subject='',$date='',$size='',$body='',$hasAttachment=false)
+    function EMail ($id,$bennoId='',$from='',$to=array(),$cc=array(),$bcc=array(),$subject='',$date='',$size='',$body='',$hasAttachment=false,$verified=false)
     {
         $this->id       = $id; 
         $this->bennoId  = $bennoId; 
@@ -77,6 +78,7 @@ class EMail
         $this->hasAttachment = $hasAttachment;
 
         $this->attachments = array();
+        $this->verified = $verified;
     }
 
     /**
@@ -245,6 +247,15 @@ class EMail
     }
 
 
+    /**
+     * Return checksum test result
+     */
+    function isVerified()
+    {
+        return $this->verified;
+    }
+
+
     /**
      * Add attachment object to attachment list
      */
