@@ -35,7 +35,8 @@
 class MailObject
 {
 
-    var $id;
+    var $id;        // searchId
+    var $bennoId;   // repo id
     var $from;
     var $to;
     var $cc;
@@ -48,9 +49,10 @@ class MailObject
     var $bodytype;
 
 
-    function MailObject($id,$from='',$to='',$cc='',$bcc='',$subject='',$date='',$time='',$size='',$body='',$attachments=array())
+    function MailObject($id,$bennoId,$from='',$to='',$cc='',$bcc='',$subject='',$date='',$time='',$size='',$body='',$attachments=array())
     {
         $this->id       = $id; 
+        $this->id       = $bennoId; 
         $this->from     = $from;
         $this->to       = $to;
         $this->cc       = $cc;
