@@ -43,14 +43,14 @@ class Query
 
     var $text;              // content or search term
     var $sender;
-    var $recipient;
-    var $subject;
+    var $recipient; var $subject;
     var $headerName;        // will only be set on extended search
     var $headerValue;       // will only be set on extended search
     var $isAttachment;
     var $isSpam;
     var $dateFrom;          // 01.01.1970
     var $dateTo;            // 31.12.2011
+    var $type;              // Type of this query: Simple, Ext, Konv
 
     /**
      * array with sort conditions
@@ -58,13 +58,12 @@ class Query
      *   array('field' => 'Date', 'ascending' => 'false')
      */
     var $sort;
-    var $displayname;       // name shown in user interface
 
 
     /**
      * Query constructor
      */
-    function Query ($id,$text='',$dateFrom='',$dateTo='',$sender='',$recipient='',$subject='',$headerName='',$headerValue='',$isAttachment=false,$isSpam=false,$displayname='')
+    function Query ($id,$text='',$dateFrom='',$dateTo='',$sender='',$recipient='',$subject='',$headerName='',$headerValue='',$isAttachment=false,$isSpam=false,$type='Simple')
     {
         $this->id = $id;
         $this->text = $text;          // content or search term
@@ -78,7 +77,7 @@ class Query
         $this->isAttachment = $isAttachment;
         $this->isSpam = $isSpam;
         $this->sort  = array('field' => 'Date', 'ascending' => 'false');
-        $this->displayname = $displayname;
+        $this->type = $type;
     }
 
 
@@ -121,15 +120,24 @@ class Query
         global $App;
         $query_string = '';
 
-        if ($this->headerName) {            // every other param could be ''
+        if ($this->type == 'Simple') {            // Simple, Ext, Konv
+            $query_string = $this->_simpleQuery();
+        }
+        else if ($this->type == 'BennoId') {
+            if ($this->text) {
+                $idString = str_replace(':','/',$this->text);
+                $query_string = '#RepoPath:'.$idString;
+            }
+            else {
+                $query_string = 'id:notinindex';
+            }
+        }
+        else {
             // extended query
             $query_string = $this->_extendedQuery();
         }
-        else {
-            $query_string = $this->_simpleQuery();
-        }
 
-        $App->log('[Query] '.$query_string,3);
+        $App->log("Query string: $query_string",3,'Query');
         // replace special chars
         $search = array('&');
         $replace = array('%26');
@@ -263,41 +271,34 @@ class Query
 
         $query_string = '';
 
-        if ($this->sender !== '') {
-            $sender_q = $this->sender.'*';
-            if (!$App->getConfig('SUPPRESS_LEADING_WILDCARD')) {
-                $sender_q = '*'.$this->sender.'*';
-            }
-            $sender_string = $this->_format_query($sender_q,'Sender');
-            // (!)Sender contains plain email adress without names
-            $from_string   = $this->_format_query($sender_q,'From');
-            $sender_query .= '('.$sender_string.$or.$from_string.')';
-        }
 
-        if ($this->recipient !== '') {
-            $recipient_q = $this->recipient.'*';
-            if (!$App->getConfig('SUPPRESS_LEADING_WILDCARD')) {
-                $recipient_q = '*'.$this->recipient.'*';
+        if ($this->type == 'Konv') {
+            if ($this->sender && $this->recipient) {
+                $p1s = $this->_asm_sender_query($this->sender);
+                $p1r = $this->_asm_recipient_query($this->recipient);
+                $p2s = $this->_asm_sender_query($this->recipient);
+                $p2r = $this->_asm_recipient_query($this->sender);
+
+                $query_string .= '(('.$p1s.$and.$p1r.')'.$or.
+                                  '('.$p2s.$and.$p2r.'))'.$and;
+            }  // Communication with one recipient will bei ORed
+            else if (!$this->sender && $this->recipient) {
+                $p1s = $this->_asm_sender_query($this->recipient);
+                $p1r = $this->_asm_recipient_query($this->recipient);
+                $query_string .= '('.$p1s.$or.$p1r.')'.$and;
+            }
+            else if (!$this->recipient && $this->sender) {
+                $p1s = $this->_asm_sender_query($this->sender);
+                $p1r = $this->_asm_recipient_query($this->sender);
+                $query_string .= '('.$p1s.$or.$p1r.')'.$and;
             }
-            // (!)Recipient contains plain email adress without names
-            $recipient_string = $this->_format_query($recipient_q,'Recipient');
-            $to_string        = $this->_format_query($recipient_q,'To');
-            $cc_string        = $this->_format_query($recipient_q,'Cc');
-            $recipient_query .= '('.$recipient_string.$or.
-                                 $to_string.$or.
-                                 $cc_string.')';
-        }
-        // Communication with one recipient will bei ORed
-        if (($this->sender == $this->recipient) &&
-            ($sender_query && $recipient_query)) {
-            $query_string .= '('.$sender_query.$or.$recipient_query.')'.$and;
         }
         else {
-            if ($sender_query) {
-                $query_string .= $sender_query.$and;
+            if ($this->sender) {
+                $query_string .= $this->_asm_sender_query($this->sender).$and;
             }
-            if ($recipient_query) {
-                $query_string .= $recipient_query.$and;
+            if ($this->recipient) {
+                $query_string .= $this->_asm_recipient_query($this->recipient).$and;
             }
         }
 
@@ -341,11 +342,59 @@ class Query
 
         $date_range   = $this->_dateRange($this->dateFrom,$this->dateTo);
         $query_string .= $date_range;
-
+        $App->log("Querystring: $query_string",4,'Query');
         return $query_string;
     }
 
 
+    /**
+     * assemble sender query string
+     */
+    function _asm_sender_query ($participant) {
+        if ($participant == '') { return ''; }
+
+        global $App;
+        $sender_q = $participant.'*';
+        if (!$App->getConfig('SUPPRESS_LEADING_WILDCARD')) {
+            $sender_q = '*'.$participant.'*';
+        }
+        $sender_string = $this->_format_query($sender_q,'Sender');
+        // (!)Sender contains plain email adress without names
+        $from_string   = $this->_format_query($sender_q,'From');
+        $sender_query .= '('.$sender_string.$or.$from_string.')';
+
+        return $sender_query;
+    }
+
+
+    /**
+     * assemble recipient query string
+     */
+    function _asm_recipient_query ($participant) {
+        if ($participant == '') { return ''; }
+
+        global $App;
+        $recipient_q = $participant.'*';
+        if (!$App->getConfig('SUPPRESS_LEADING_WILDCARD')) {
+            $recipient_q = '*'.$participant.'*';
+        }
+        // (!)Recipient contains plain email adress without names
+        $recipient_string = $this->_format_query($recipient_q,'Recipient');
+        $to_string        = $this->_format_query($recipient_q,'To');
+        $cc_string        = $this->_format_query($recipient_q,'Cc');
+        $recipient_query .= '('.$recipient_string.$or.
+                             $to_string.$or.
+                             $cc_string.')';
+
+        return $recipient_query;
+    }
+
+
+
+
+
+
+
     /**
      * format querystring
     */
